summaryrefslogtreecommitdiff
path: root/platform/darwin/src/http_file_source.mm
diff options
context:
space:
mode:
Diffstat (limited to 'platform/darwin/src/http_file_source.mm')
-rw-r--r--platform/darwin/src/http_file_source.mm4
1 files changed, 2 insertions, 2 deletions
diff --git a/platform/darwin/src/http_file_source.mm b/platform/darwin/src/http_file_source.mm
index eb751258c8..a678b6e5cb 100644
--- a/platform/darwin/src/http_file_source.mm
+++ b/platform/darwin/src/http_file_source.mm
@@ -130,7 +130,7 @@ NSString *HTTPFileSource::Impl::getUserAgent() const {
}
}
// Avoid %s here because it inserts hidden bidirectional markers on OS X when the system
// language is set to a right-to-left language.
[userAgentComponents addObject:[NSString stringWithFormat:@"MapboxGL/%@ (%@)",
CFSTR(MBGL_VERSION_STRING), CFSTR(MBGL_VERSION_REV)]];
@@ -139,7 +139,7 @@ NSString *HTTPFileSource::Impl::getUserAgent() const {
#if TARGET_OS_IPHONE
systemName = @"iOS";
#elif TARGET_OS_MAC
- systemName = @"OS X";
+ systemName = @"macOS";
#elif TARGET_OS_WATCH
systemName = @"watchOS";
#elif TARGET_OS_TV
@@ -130,7 +130,7 @@ NSString *HTTPFileSource::Impl::getUserAgent() const {
}
}
- // Avoid %s here because it inserts hidden bidirectional markers on OS X when the system
+ // Avoid %s here because it inserts hidden bidirectional markers on macOS when the system
// language is set to a right-to-left language.
[userAgentComponents addObject:[NSString stringWithFormat:@"MapboxGL/%@ (%@)",